@@ -8,7 +8,7 @@ use Language::FormulaEngine::Parser::ContextUtil
 use namespace::clean;
 
 # ABSTRACT: Create parse tree from an input string
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 
 has parse_tree   => ( is => 'rw' );
@@ -289,7 +289,11 @@ BEGIN {
 			
 			# Check for numbers
 			if ($self->{input} =~ /\G([0-9]*\.?[0-9]+(?:[eE][+-]?[0-9]+)?)\b/gc) {
-				return Number => $1;
+				return Number => $1+0;
+			}
+			# or hex numbers
+			if ($self->{input} =~ /\G0x([0-9A-Fa-f]+)/gc) {
+				return Number => hex($1);
 			}
 			
 			# Check for any keyword, and convert the type to the canonical (lowercase) name.
@@ -383,7 +387,7 @@ Language::FormulaEngine::Parser - Create parse tree from an input string
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -415,7 +419,7 @@ contain useful diagnostic information.
 
 =head2 parse_tree
 
-This holds the generated parse tree, or C<undef> if the parse failed.  See L</"PARSE NODES">.
+This holds the generated parse tree, or C<undef> if the parse failed.  See L</"Parse Nodes">.
 
 =head2 error
 
@@ -565,6 +569,15 @@ and optional exponent, ending at either the end of the input or a non-alphanumer
 A single-quoted or double-quoted string, treating a double occurrence of the quote
 character to mean a literal quote character.  ("Pascal style")
 
+  'apostrophes are''nt hard'
+
+There are no escape sequences though, so to get control characters or awkward unicode
+into a string you need something like:
+
+  concat("smile ",char(0x263A))
+
+which depends on those functions being available in the namespace.
+
 =item Keywords...
 
 Keywords include the "word" tokens like 'OR', but also every text literal seen in a parse rule
@@ -582,21 +595,23 @@ Any alpha (or underscore) followed by any run of alphanumerics,
 =head2 Parse Nodes
 
 The parse tree takes a minimalist approach to node classification.  In this default
-implementation, numbers are represented as plain perl scalars, strings and symbolic references
-are represented as blessed scalar refs, and function calls are represented as blessed Lisp-style
-arrayrefs.
+implementation, number values, string values, and symbolic references have just a simple
+wrapper around the value, and function calls are just a pair of function name and list of
+arguments.  All language operators are represented as function calls.
 
 A blessed node only needs to support one method: C<< ->evaluate($namespace) >>.
 
 The class name of the blessed nodes should be ignored.  A function is anything which
-C<< can("function_name") >>, a string is anything which C<< can("string_value") >> and a
-symbolic reference is anything which C<< can("symbolic_name") >>.  Also, the blessed strings
-automatically stringify to their value, behaving almost like plain perl scalars.
+C<< can("function_name") >>, a string is anything which C<< can("string_value") >>, a number is
+anything which C<< can("number_value") >> and a symbolic reference is anything which
+C<< can("symbolic_name") >>.
 
 Subclasses of Parser should implemnt new node types as needed.  You probable also need to
 update L</deparse>.
 
-The parser rules create nodes by methods on the Parser class, for easy subclassing.
+The parser rules (C<parse_X_expr> methods) create nodes by the following methods on the Parser
+class, so that you can easily subclass C<Parser> and override which class of node is getting
+created.
 
 =over
 
